==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/mixer/v1/CheckResponse.java <==

package me.snowdrop.istio.api.mixer.v1;

import java.io.Serializable;
import java.util.Map;
import javax.validation.Valid;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import io.sundr.builder.annotations.Inline;
import lombok.EqualsAndHashCode;
import lombok.ToString;


/**
 * 
 * 
 */
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "precondition",
    "quotas"
})
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, validationEnabled = true, generateBuilderPackage = true, builderPackage = "io.fabric8.kubernetes.api.builder", inline = {
    @Inline(type = Doneable.class, prefix = "Doneable", value = "done")
}, refs = {
    @BuildableReference(ObjectMeta.class)
})
public class CheckResponse implements Serializable
{

    /**
     * 
     * 
     */
    @JsonProperty("precondition")
    @JsonPropertyDescription("")
    @Valid
    private PreconditionResult precondition;
    /**
     * 
     * 
     */
    @JsonProperty("quotas")
    @JsonPropertyDescription("")
    @Valid
    private Map<String, QuotaResult> quotas;
    private final static long serialVersionUID = 6521155807135740814L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public CheckResponse() {
    }

    /**
     * 
     * @param quotas
     * @param precondition
     */
    public CheckResponse(PreconditionResult precondition, Map<String, QuotaResult> quotas) {
        super();
        this.precondition = precondition;
        this.quotas = quotas;
    }

    /**
     * 
     * 
     */
    @JsonProperty("precondition")
    public PreconditionResult getPrecondition() {
        return precondition;
    }

    /**
     * 
     * 
     */
    @JsonProperty("precondition")
    public void setPrecondition(PreconditionResult precondition) {
        this.precondition = precondition;
    }

    /**
     * 
     * 
     */
    @JsonProperty("quotas")
    public Map<String, QuotaResult> getQuotas() {
        return quotas;
    }

    /**
     * 
     * 
     */
    @JsonProperty("quotas")
    public void setQuotas(Map<String, QuotaResult> quotas) {
        this.quotas = quotas;
    }

}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/mixer/v1/CheckResponse.java <==

package me.snowdrop.istio.api.mixer.v1;

import java.io.Serializable;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import io.sundr.builder.annotations.Inline;
import lombok.EqualsAndHashCode;
import lombok.ToString;


/**
 * 
 * 
 */
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "precondition",
    "quotas"
})
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, generateBuilderPackage = true, builderPackage = "io.fabric8.kubernetes.api.builder", inline = {
    @Inline(type = Doneable.class, prefix = "Doneable", value = "done")
}, refs = {
    @BuildableReference(ObjectMeta.class)
})
public class CheckResponse implements Serializable
{

    /**
     * 
     * 
     */
    @JsonProperty("precondition")
    @JsonPropertyDescription("")
    private PreconditionResult precondition;
    /**
     * 
     * 
     */
    @JsonProperty("quotas")
    @JsonPropertyDescription("")
    private Map<String, QuotaResult> quotas;
    private final static long serialVersionUID = 6521155807135740814L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public CheckResponse() {
    }

    /**
     * 
     * @param quotas
     * @param precondition
     */
    public CheckResponse(PreconditionResult precondition, Map<String, QuotaResult> quotas) {
        super();
        this.precondition = precondition;
        this.quotas = quotas;
    }

    /**
     * 
     * 
     */
    @JsonProperty("precondition")
    public PreconditionResult getPrecondition() {
        return precondition;
    }

    /**
     * 
     * 
     */
    @JsonProperty("precondition")
    public void setPrecondition(PreconditionResult precondition) {
        this.precondition = precondition;
    }

    /**
     * 
     * 
     */
    @JsonProperty("quotas")
    public Map<String, QuotaResult> getQuotas() {
        return quotas;
    }

    /**
     * 
     * 
     */
    @JsonProperty("quotas")
    public void setQuotas(Map<String, QuotaResult> quotas) {
        this.quotas = quotas;
    }

}
